@@ -1,10 +1,10 @@
 package SQL::Translator::Filter::AutoCRUD::ExtJSxType;
 {
-  $SQL::Translator::Filter::AutoCRUD::ExtJSxType::VERSION = '2.142820';
+  $SQL::Translator::Filter::AutoCRUD::ExtJSxType::VERSION = '2.143070';
 }
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 my %xtype_for = (
     boolean => 'checkbox',
